@@ -2,27 +2,62 @@
 # Author   :buxiubuzhi
 # time     :2020/2/13  14:44
 # ---------------------------------------
-from .config import Config
+import functools
+
+from lazyTest.config import Config
 from selenium.webdriver.support.select import Select
 from selenium.webdriver.common.action_chains import ActionChains
 
 
+def _retrying(func):
+    @functools.wraps(func)
+    def inner(*args):
+        # 如果是字符串，直接传入不进行重试
+        if isinstance(args[1], str):
+            result = func(*args)
+            return result
+        ele = iter(args[1])  # 非字符串，创建迭代器
+
+        # 实现重试机制，报错就会重试，直到迭代所有
+        def run(ele,*args):
+            args = list(args)       # 兼容多个参数
+            try:
+                e = next(ele)
+            except StopIteration:
+                return
+            try:
+                args[1] = e         # 处理时只处理第一个参数
+                result = func(*args)
+                return result
+            except BaseException as e:  # 捕获所有异常
+                result = run(ele,*args)
+            return result
+
+        result = run(ele,*args)
+        return result
+
+    return inner
+
+
 class WebOption(Config):
 
     def Get(self, url: str) -> None:
         urls = self.baseUrl + url
         self.baseDriver.get(urls)
 
+    @_retrying
     def Click(self, selector: str) -> None:
         """元素点击操作"""
         ele = self.locate_element(selector)
         ele.click()
 
+    @_retrying
     def RightClick(self, selector: str) -> None:
         """鼠标右键"""
         ele = self.locate_element(selector)
         ActionChains(self.baseDriver).context_click(selector)
 
+    @_retrying
     def DoubleClick(self, selector: str) -> None:
         """元素双击"""
         ele = self.locate_element(selector)
@@ -34,32 +69,38 @@ class WebOption(Config):
         end = self.locate_element(target)
         ActionChains(self.baseDriver).drag_and_drop(start, end)
 
+    @_retrying
     def ActionScroll(self, selector: str, x: int = 0, y: int = 10):
         """内嵌滚动条滚动"""
         ele = self.locate_element(selector)
         ActionChains(self.baseDriver).drag_and_drop_by_offset(ele, x, y).perform()
 
+    @_retrying
     def Input(self, selector: str, value: str) -> None:
         """元素输入操作"""
         ele = self.locate_element(selector)
         ele.send_keys(value)
 
+    @_retrying
     def Clear(self, selector: str) -> None:
         """元素输入框清空输入内容"""
         ele = self.locate_element(selector)
         ele.clear()
 
+    @_retrying
     def ClearAndInput(self, selector: str, value: str) -> None:
         """清空输入框并输入内容"""
         ele = self.locate_element(selector)
         ele.clear()
         ele.send_keys(value)
 
+    @_retrying
     def GetText(self, selector: str) -> str:
         """获取元素文本内容"""
         ele = self.locate_element(selector)
         return ele.text
 
+    @_retrying
     def GetTexts(self, selector: str, index: int = None) -> list:
         """获取一组元素的文本内容"""
         ele = self.locate_elements(selector)
@@ -69,6 +110,7 @@ class WebOption(Config):
             text_list = [i.text for i in ele]
             return text_list
 
+    @_retrying
     def GetElements(self, selector: str, index: int = None) -> list:
         """获取一组元素"""
         ele = self.locate_elements(selector)
@@ -77,6 +119,7 @@ class WebOption(Config):
         else:
             return ele
 
+    @_retrying
     def GetAttribute(self, selector: str, value: str = 'value') -> str:
         """
         获取元素属性
@@ -86,6 +129,7 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         return ele.get_attribute(value)
 
+    @_retrying
     def AddAttribute(self, selector: str, attributeName: str, value: str):
         '''
         封装向页面标签添加新属性的方法
@@ -93,14 +137,16 @@ class WebOption(Config):
         ele = self.locate_element(selector)
         self.baseDriver.execute_script("arguments[0].%s=arguments[1]" % attributeName, ele, value)
 
+    @_retrying
     def SetAttribute(self, selector: str, attributeName: str, value: str):
         '''
         封装设置页面对象的属性值的方法
         '''
         ele = self.locate_element(selector)
         self.baseDriver.execute_script("arguments[0].setAttribute(arguments[1],arguments[2])", ele, attributeName,
-                                        value)
+                                       value)
 
+    @_retrying
     def SwitchFrame(self, selector: str) -> None:
         """根据框架定位元素值切换"""
         ele = self.locate_element(selector)
@@ -127,6 +173,7 @@ class WebOption(Config):
         elif operation == 'dismiss':
             alert.dismiss()
 
+    @_retrying
     def SelectOperation(self, selector: str, operation_type: str, value: str) -> None:
         """下拉框处理"""
         if operation_type == 'index':
@@ -168,6 +215,7 @@ class WebOption(Config):
             get_js = f"window.scrollBy(0,{i});"  # 执行多个js脚本则需要用到scrollBy；表示再次下拉到300位置
             self.baseDriver.execute_script(get_js)  # 执行js脚本
 
+    @_retrying
     def getALlPageText(self, selector: str) -> list:
         """获取整个页面的一组元素文本，包括没有显示在当前窗口的"""
         js = "return arguments[0].textContent"
