@@ -6,7 +6,7 @@
 import argparse
 import os, sys
 from lazyTest import __version__, __description__
-
+from lazyTest.template import TEMP
 PY3 = sys.version_info[0] == 3
 
 
@@ -38,7 +38,7 @@ def main():
         return 0
 
 
-from template import TEMP
+
 
 
 def create_scaffold(project_name):
