@@ -7,20 +7,23 @@ from typing import List
 from ruamel import yaml
 
 
+PAGE = "page"
+ELE = "ele"
+
 class Page:
     Document = ""
-    Element = ""
+    Element = None
     Type = ""
 
     def __init__(self, **kwargs):
-        self.Element = kwargs["ele"]
+        self.Element = kwargs[ELE]
 
 
 class Source:
     page = {}
 
     def __init__(self, **kwargs):
-        self.page = kwargs["page"]
+        self.page = kwargs[PAGE]
 
     def GetAllKey(self) -> List:
         keys = [i for i in self.page]
