@@ -1,14 +1,14 @@
 # -*- coding = UTF-8 -*-
 # Author   :buxiubuzhi
 # File     : page.py
-# project  : McenterSystem
+# project  : lazyTest
 # time     : 2020/12/3 11:56
 # Describe :
 # ---------------------------------------
 
 import logging
-from .file import *
-from .base import *
+from lazyTest.file import *
+from lazyTest.base import *
 
 
 class Page(object):
@@ -28,7 +28,7 @@ class Page(object):
             self.GetProjectPath() + self.filePath + self.getClassName() + self.suffix
         )
 
-    def GetElement(self, key: str) -> str:
+    def GetElement(self, key: str):
         return self.source.GetElement(key).Element
 
     def GetProjectPath(self) -> str: ...
